@@ -56,9 +56,12 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
-import aws_cdk.core
+import aws_cdk
+import constructs
 
 
 @jsii.enum(
@@ -98,6 +101,10 @@ class AspectPropsBase:
         :param annotation_text: The annotation text to use for the annotation.
         :param annotation_type: The annotation type to use for the annotation.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AspectPropsBase.__init__)
+            check_type(argname="argument annotation_text", value=annotation_text, expected_type=type_hints["annotation_text"])
+            check_type(argname="argument annotation_type", value=annotation_type, expected_type=type_hints["annotation_type"])
         self._values: typing.Dict[str, typing.Any] = {}
         if annotation_text is not None:
             self._values["annotation_text"] = annotation_text
@@ -163,6 +170,14 @@ class AspectPropsExtended(AspectPropsBase):
         :param restricted_cidrs: The restricted CIDRs for the given port. Default: ['0.0.0.0/0', '::/0']
         :param restricted_s_gs: The restricted source security groups for the given port. Default: undefined
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AspectPropsExtended.__init__)
+            check_type(argname="argument annotation_text", value=annotation_text, expected_type=type_hints["annotation_text"])
+            check_type(argname="argument annotation_type", value=annotation_type, expected_type=type_hints["annotation_type"])
+            check_type(argname="argument any_source", value=any_source, expected_type=type_hints["any_source"])
+            check_type(argname="argument ports", value=ports, expected_type=type_hints["ports"])
+            check_type(argname="argument restricted_cidrs", value=restricted_cidrs, expected_type=type_hints["restricted_cidrs"])
+            check_type(argname="argument restricted_s_gs", value=restricted_s_gs, expected_type=type_hints["restricted_s_gs"])
         self._values: typing.Dict[str, typing.Any] = {}
         if annotation_text is not None:
             self._values["annotation_text"] = annotation_text
@@ -264,7 +279,7 @@ class RuleCheckArgs(AspectPropsExtended):
         ports: typing.Optional[typing.Sequence[jsii.Number]] = None,
         restricted_cidrs: typing.Optional[typing.Sequence[builtins.str]] = None,
         restricted_s_gs: typing.Optional[typing.Sequence[builtins.str]] = None,
-        node: aws_cdk.core.IConstruct,
+        node: constructs.IConstruct,
     ) -> None:
         '''The arguments for the checkRules function.
 
@@ -278,6 +293,15 @@ class RuleCheckArgs(AspectPropsExtended):
         :param restricted_s_gs: The restricted source security groups for the given port. Default: undefined
         :param node: The node to check.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RuleCheckArgs.__init__)
+            check_type(argname="argument annotation_text", value=annotation_text, expected_type=type_hints["annotation_text"])
+            check_type(argname="argument annotation_type", value=annotation_type, expected_type=type_hints["annotation_type"])
+            check_type(argname="argument any_source", value=any_source, expected_type=type_hints["any_source"])
+            check_type(argname="argument ports", value=ports, expected_type=type_hints["ports"])
+            check_type(argname="argument restricted_cidrs", value=restricted_cidrs, expected_type=type_hints["restricted_cidrs"])
+            check_type(argname="argument restricted_s_gs", value=restricted_s_gs, expected_type=type_hints["restricted_s_gs"])
+            check_type(argname="argument node", value=node, expected_type=type_hints["node"])
         self._values: typing.Dict[str, typing.Any] = {
             "node": node,
         }
@@ -347,11 +371,11 @@ class RuleCheckArgs(AspectPropsExtended):
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
     @builtins.property
-    def node(self) -> aws_cdk.core.IConstruct:
+    def node(self) -> constructs.IConstruct:
         '''The node to check.'''
         result = self._values.get("node")
         assert result is not None, "Required property 'node' is missing"
-        return typing.cast(aws_cdk.core.IConstruct, result)
+        return typing.cast(constructs.IConstruct, result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -365,7 +389,7 @@ class RuleCheckArgs(AspectPropsExtended):
         )
 
 
-@jsii.implements(aws_cdk.core.IAspect)
+@jsii.implements(aws_cdk.IAspect)
 class SecurityGroupAspectBase(
     metaclass=jsii.JSIIMeta,
     jsii_type="@renovosolutions/cdk-aspects-library-security-group.SecurityGroupAspectBase",
@@ -405,50 +429,65 @@ class SecurityGroupAspectBase(
         jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="visit")
-    def visit(self, node: aws_cdk.core.IConstruct) -> None:
+    def visit(self, node: constructs.IConstruct) -> None:
         '''All aspects can visit an IConstruct.
 
         :param node: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SecurityGroupAspectBase.visit)
+            check_type(argname="argument node", value=node, expected_type=type_hints["node"])
         return typing.cast(None, jsii.invoke(self, "visit", [node]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="annotationText")
     def annotation_text(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "annotationText"))
 
     @annotation_text.setter
     def annotation_text(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(SecurityGroupAspectBase, "annotation_text").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "annotationText", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="annotationType")
     def annotation_type(self) -> AnnotationType:
         return typing.cast(AnnotationType, jsii.get(self, "annotationType"))
 
     @annotation_type.setter
     def annotation_type(self, value: AnnotationType) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(SecurityGroupAspectBase, "annotation_type").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "annotationType", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="anySource")
     def any_source(self) -> builtins.bool:
         return typing.cast(builtins.bool, jsii.get(self, "anySource"))
 
     @any_source.setter
     def any_source(self, value: builtins.bool) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(SecurityGroupAspectBase, "any_source").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "anySource", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ports")
     def ports(self) -> typing.Optional[typing.List[jsii.Number]]:
         return typing.cast(typing.Optional[typing.List[jsii.Number]], jsii.get(self, "ports"))
 
     @ports.setter
     def ports(self, value: typing.Optional[typing.List[jsii.Number]]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(SecurityGroupAspectBase, "ports").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ports", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="restrictedCidrs")
     def restricted_cidrs(self) -> typing.Optional[typing.List[builtins.str]]:
         return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "restrictedCidrs"))
@@ -458,9 +497,12 @@ class SecurityGroupAspectBase(
         self,
         value: typing.Optional[typing.List[builtins.str]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(SecurityGroupAspectBase, "restricted_cidrs").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "restrictedCidrs", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="restrictedSGs")
     def restricted_s_gs(self) -> typing.Optional[typing.List[builtins.str]]:
         return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "restrictedSGs"))
@@ -470,6 +512,9 @@ class SecurityGroupAspectBase(
         self,
         value: typing.Optional[typing.List[builtins.str]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(SecurityGroupAspectBase, "restricted_s_gs").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "restrictedSGs", value)
 
 
@@ -563,7 +608,7 @@ class NoIngressCommonWebPortsAspect(
         jsii.create(self.__class__, self, [props])
 
 
-@jsii.implements(aws_cdk.core.IAspect)
+@jsii.implements(aws_cdk.IAspect)
 class NoPublicIngressAspectBase(
     SecurityGroupAspectBase,
     metaclass=jsii.JSIIMeta,
@@ -811,7 +856,7 @@ class CISAwsFoundationBenchmark4Dot2Aspect(
         jsii.create(self.__class__, self, [props])
 
 
-@jsii.implements(aws_cdk.core.IAspect)
+@jsii.implements(aws_cdk.IAspect)
 class NoPublicIngressAspect(
     NoPublicIngressAspectBase,
     metaclass=jsii.JSIIMeta,
